try:
    from tuneup.ndimraces import sigopt_versus_shgo_deap
except ImportError:
    pass
from tuneup.ndimraces import open_source_race
